@@ -2,6 +2,9 @@ from .models import ObjectPermission
 
 
 class PermissionBackend(object):
+    supports_object_permissions = True
+    supports_anonymous_user = True
+    supports_inactive_user = True
 
     def authenticate(self):
         """
